@@ -1,6 +1,6 @@
 # flake8: noqa
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 from .client import initialize
 
@@ -19,6 +19,7 @@ from .property import (
 )
 
 from .exceptions import (
-    FirestoreGlueValidationError,
-    FirestoreGlueProgrammingError
+    FsglueException,
+    FsglueProgrammingError,
+    FsglueValidationError
 )
